@@ -2,36 +2,34 @@
 //! calculations.
 
 mod drop;
-mod farm;
 mod stew;
 mod xp;
 
 use crate::{
     commands::{
         calc::{
-            drop::CalcDropCommand, farm::CalcFarmCommand,
-            stew::CalcStewCommand, xp::CalcXpCommand,
+            drop::CalcDropCommand, stew::CalcStewCommand, xp::CalcXpCommand,
         },
         Command, CommandType,
     },
     utils::context::CommandContext,
 };
+use async_trait::async_trait;
+use std::io::Write;
 use structopt::StructOpt;
 
 #[derive(Debug, StructOpt)]
 pub enum CalcCommandType {
     Drop(CalcDropCommand),
     Stew(CalcStewCommand),
-    Farm(CalcFarmCommand),
     Xp(CalcXpCommand),
 }
 
-impl CommandType for CalcCommandType {
-    fn command(&self) -> &dyn Command {
+impl<O: Write> CommandType<O> for CalcCommandType {
+    fn command(&self) -> &dyn Command<O> {
         match &self {
             Self::Drop(cmd) => cmd,
             Self::Stew(cmd) => cmd,
-            Self::Farm(cmd) => cmd,
             Self::Xp(cmd) => cmd,
         }
     }
@@ -44,8 +42,12 @@ pub struct CalcCommand {
     pub cmd: CalcCommandType,
 }
 
-impl Command for CalcCommand {
-    fn execute(&self, context: &CommandContext) -> anyhow::Result<()> {
-        self.cmd.command().execute(context)
+#[async_trait(?Send)]
+impl<O: Write> Command<O> for CalcCommand {
+    async fn execute(&self, context: CommandContext<O>) -> anyhow::Result<()>
+    where
+        O: 'async_trait,
+    {
+        self.cmd.command().execute(context).await
     }
 }
