@@ -1,11 +1,10 @@
-pub mod console;
+#[cfg(wasm)]
+pub mod browser;
 pub mod context;
-pub mod diary;
-pub mod farm;
 pub mod fmt;
 pub mod hiscore;
 pub mod http;
 pub mod item;
-pub mod magic;
 pub mod math;
 pub mod skill;
+pub mod table;
